==> oeshop_0.03.tar.gz: oeshop/shop_list/skin_prize.php <==
<?
//history 
echo "history:<a href='$PHP_SELF?category_code=$category[0]'>".$h1."</a>><a href='$PHP_SELF?category_code=$category2'>".$h2."</a>>".$h3."<br><br><br>";


//ǰ  κ
echo "<table width=600 border=0 cellpadding=2 cellspacing=0>
	<tr height=30>
		<td>&nbsp;&nbsp;&nbsp; ".$total_data."  ǰ غǾϴ.</td>
		<td align=center colspan=3>";
			include "./paging.php";
		echo"</td>
	</tr>
	<tr align=center height=30>
		<td width=400 style='border-bottom:solid 1 #000000 ; border-top:solid 1 #000000'>ǰ</td>
		<td width=80 style='border:solid 1 #000000'>ǸŰ</td>
		<td width=80 style='border-bottom:solid 1 #000000 ; border-top:solid 1 #000000 ;	 border-right:solid 1 #000000'>Ʈ</td>
		<td width=40 style='border-bottom:solid 1 #000000 ; border-top:solid 1 #000000'></td>
	</tr>
	</table>
	<table width=600 cellpadding=2 cellspacing=0>
	<tr><td style='font-size: 5pt'>&nbsp;</td></tr>
";
for($i=0; $i<$total; $i++){
	$row=mysql_fetch_array($result);
	echo"<tr>
		<td width=400 style='border-bottom:solid 1 #9d9d9d'>&nbsp;&nbsp;&nbsp;(ǰ̹) $row[prize_name]</td>
		<td width=60 align=right  style='border-bottom:solid 1 #9d9d9d'>$row[prize_sail2]</td>
		<td width=100 align=center  style='border-bottom:solid 1 #9d9d9d'>$row[prize_point]</td>
		<td width=40 align=center style='border-bottom:solid 1 #9d9d9d'><img src='./image/cart.gif'></td>
	</tr>";

}
	echo "<tr><td colspan=4 style='border-bottom:solid 1 #000000'>&nbsp;</td></tr>
	<tr height=30><td colspan=4 align=center>";
		include "./paging.php";
	echo "</td></tr>
	</table>";
?>

==> oeshop_0.07.tar.gz: oeshop/shop_list/skin_prize.php <==
<?
//history 
echo "history:<a href='$PHP_SELF?category_code=$category[0]'>".$h1."</a>><a href='$PHP_SELF?category_code=$category2'>".$h2."</a>>".$h3."<br><br><br>";


//ǰ  κ
echo "<table width=600 border=0 cellpadding=2 cellspacing=0>
	<tr height=30>
		<td>&nbsp;&nbsp;&nbsp; ".$total_data."  ǰ غǾϴ.</td>
		<td align=right colspan=3>";
			include "./paging.php";
		echo"</td>
	</tr>
	<tr align=center height=30>
		<td width=400 style='border-bottom:solid 1 #000000 ; border-top:solid 1 #000000'>ǰ</td>
		<td width=80 style='border:solid 1 #000000'>ǸŰ</td>
		<td width=80 style='border-bottom:solid 1 #000000 ; border-top:solid 1 #000000 ;	 border-right:solid 1 #000000'>Ʈ</td>
		<td width=40 style='border-bottom:solid 1 #000000 ; border-top:solid 1 #000000'></td>
	</tr>
	</table>
	<table width=600 cellpadding=2 cellspacing=0>
	<tr><td style='font-size: 5pt'>&nbsp;</td></tr>
";
for($i=0; $i<$total; $i++){
	$row=mysql_fetch_array($result);
	echo"<tr>
		<td width=400 style='border-bottom:solid 1 #9d9d9d'>
			<a href='./prize_view.php?id=$row[id]&category_code=$category_code'>&nbsp;&nbsp;&nbsp;(ǰ̹) $row[prize_name]</a>
		</td>
		<td width=60 align=right  style='border-bottom:solid 1 #9d9d9d'>$row[prize_sail2]</td>
		<td width=100 align=center  style='border-bottom:solid 1 #9d9d9d'>$row[prize_point]</td>
		<td width=40 align=center style='border-bottom:solid 1 #9d9d9d'><img src='./image/cart.gif'></td>
	</tr>";

}
	echo "<tr><td colspan=4 style='border-bottom:solid 1 #000000'>&nbsp;</td></tr>
	<tr height=30><td colspan=4 align=center>";
		include "./paging.php";
	echo "</td></tr>
	</table>";
?>
